summaryrefslogtreecommitdiffstats
path: root/src/settings.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/settings.cpp')
-rw-r--r--src/settings.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/settings.cpp b/src/settings.cpp
index ea1aa4a..cf860e0 100644
--- a/src/settings.cpp
+++ b/src/settings.cpp
@@ -35,7 +35,7 @@
/*! This is the default constructor of the class Settings. */
Settings::Settings()
{
- tdeconfig = new TDEConfig("kpowersaverc", true );
+ tdeconfig = new TDEConfig("tdepowersaverc", true );
kde = new KDE_Settings();
load_kde();
load_general_settings();
@@ -50,7 +50,7 @@ Settings::~Settings()
/*!
* Loads the scheme settings from kpowersaverc and fills the related variables.
* \param schemeName TQString with the name (realname not i18n() version) of the
* scheme which setting should be load. If the scheme could not
* be loaded, this function try to load "default-scheme"
@@ -231,7 +231,7 @@ bool Settings::load_scheme_settings(TQString schemeName){
/*!
* Loads the general settings from kpowersaverc and fills the related variables.
* \return the result of the load
* \retval true if the settings could be loaded
* \retval false if there was no group named 'General'
@@ -50,7 +50,7 @@ Settings::~Settings()
/*!
- * Loads the scheme settings from kpowersaverc and fills the related variables.
+ * Loads the scheme settings from tdepowersaverc and fills the related variables.
* \param schemeName TQString with the name (realname not i18n() version) of the
* scheme which setting should be load. If the scheme could not
@@ -231,7 +231,7 @@ bool Settings::load_scheme_settings(TQString schemeName){
/*!
- * Loads the general settings from kpowersaverc and fills the related variables.
+ * Loads the general settings from tdepowersaverc and fills the related variables.
* \return the result of the load
* \retval true if the settings could be loaded